==> m2w-1.3.6.zip: plugin/weblog/lib/standard_edit.rb <==
# coding: UTF-8

require 'plugin/weblog/lib/attachment_media_poster'
require 'plugin/weblog/lib/related_media_poster'
require 'plugin/weblog/lib/standard_command'
require 'plugin/weblog/lib/weblog_plugin_error'
require 'plugin/weblog/lib/weblog_plugin_warning'

#=標準のブログ編集投稿用ウェブログプラグイン
#
# 最初の著者:: トゥイー
# リポジトリ情報:: $Id: standard_edit.rb 917 2012-12-22 12:59:07Z toy_dev $
# 著作権:: Copyright (C) Ownway.info, 2011 - 2012. All rights reserved.
# ライセンス:: CPL(Common Public Licence)
class StandardEdit_WeblogPlugin < StandardCommand_WeblogPlugin

	def edit(request)
		@logger.debug("Start  #{self.class.name}#edit ... endpoint = #{@parent.endpoint}, header = #{request.header.keys}") if @logger && @logger.debug?

		client = @parent.client
		formatter = @parent.formatter
		formatter.logger = @logger
		postid = request.header['postid']
		response = Mail2WeblogResponse.new

		if postid != nil then
			begin
				blogid = @parent.respond_to?('transform_blogid') ? @parent.transform_blogid(request, request.param) : request.param

				before(client, request, response)

				vars = {:blogid => blogid, :postid => postid, :encoding => @parent.encoding, M2W_FORMAT_PLUGIN_CONF_HEADER_NAME => request.header[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME]}
				vars.merge!(request.header)

				# 書式プラグインの事前処理を行う
				formatter.preset(request, vars, response.errors, response.warnings)

				# 未貼り付け画像を先頭に貼り付ける
				if request.contents['description'] then
					images = ''
					request.attachments.each_with_index do |attachment, i|
						attachment_index = i + 1
						if %r!^image/! =~ Mime.new.mime(attachment.filename) &&
								(vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME] == nil ||
								vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_PASTED_ATTACHMENT_VAR_NAME] == nil ||
								vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_PASTED_ATTACHMENT_VAR_NAME][attachment_index.to_s] == nil) then
							vars.deep_merge!(@parent.plugin_manager.call_format_plugin_preset('img', attachment_index.to_s, vars))
							images << "{{img(#{attachment_index})}}\n\n"
						end
					end
					request.contents['description'] = "#{images}#{request.contents['description']}"
				end

				# 投稿日付を取得する
				header = request.header.clone
				dateCreated = @parent.parse_date(header['dateCreated'], Time.now, response.errors, response.warnings)
				if header['dateCreated'] != nil then
					header['dateCreated'] = @parent.get_date(dateCreated)
				end

				# ファイル転送の事前準備をする
				media_posters = []
				# 添付ファイルを投稿対象に追加する
				if request.attachments != nil then
					request.attachments.each_with_index do |attachment, i|
						attachment_index = i + 1
						media_name = @parent.get_attachment_filepath(postid, dateCreated, attachment_index, attachment.filename)
						thumbnail_name = @parent.get_thumbnail_filepath(postid, dateCreated, attachment_index, attachment.filename)
						media_posters.push(AttachmentMediaPoster.new(attachment, attachment_index, media_name, thumbnail_name, vars))
					end
				end
				# 関連ファイルを投稿対象に追加する
				if request.related_attachments != nil then
					request.related_attachments.each_with_index do |related_attachment, i|
						related_attachment_index = i + 1
						media_name = "rel#{postid}_#{related_attachment_index}#{File.extname(related_attachment.filename)}"
						thumbnail_name = "relthumbs#{postid}_#{related_attachment_index}#{File.extname(related_attachment.filename)}"
						media_posters.push(RelatedMediaPoster.new(related_attachment, media_name, thumbnail_name, @parent.plugin_manager, vars))
					end
				end
				# 書式プラグインからのファイル転送指令を投稿対象に追加する
				if vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME] && vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_MEDIAS_VAR_NAME] then
					vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_MEDIAS_VAR_NAME].each do |media_name, media|
						media_posters.push(media)
					end
				end

				# ファイルを転送する
				vars[:attachment_urls] = {}
				vars[:thumbnail_urls] = {}
				vars[:related_attachment_urls] = {}
				vars[:related_thumbnail_urls] = {}
				post_medias(client, @parent.username, @parent.password, blogid, media_posters, response.errors, response.warnings)

				# 書式変換を行う
				begin
					formatted_contents = nil
					formatted_contents = formatter.format(request, vars, response.errors, response.warnings)
					header.merge!(formatted_contents)
				rescue => e
					@logger.error("ブログ記事の書式変換に失敗しました。") if @logger
					@logger.error(e) if @logger
					response.errors.push(WeblogPluginError.new(
						"書式変換エラー(メッセージ = #{e.message})",
						"ブログ記事の書式変換に失敗しました(メッセージ = #{e.message})。"))
					@logger.debug("Finish #{self.class.name}#edit ... result = false") if @logger && @logger.debug?
					return response
				end

				# ブログ記事を編集投稿する
				begin
					edit_article(client, blogid, postid, header, dateCreated)
				rescue => e
					@logger.error("ブログ記事の編集に失敗しました。") if @logger
					@logger.error(e) if @logger
					response.errors.push(WeblogPluginError.new(
						"ブログ記事編集エラー(メッセージ = #{e.message})",
						"ブログ記事の編集に失敗しました(メッセージ = #{e.message})。"))
					@logger.debug("Finish #{self.class.name}#edit ... result = false") if @logger && @logger.debug?
					return response
				end

				response[:original_content] = request.original_content
				response[:blogid] = blogid.to_s
				response[:postid] = postid.to_s
				response[:attachment_urls] = vars[:attachment_urls]
				response[:thumbnail_urls] = vars[:thumbnail_urls]
				response[:title] = header['title']
				response[:formatted_contents] = formatted_contents

				after(client, request, response)

				@logger.debug("Finish #{self.class.name}#edit ... result = true") if @logger && @logger.debug?
				response.success = true
				return response
			rescue => e
				@logger.error("ブログ記事の編集に失敗しました。") if @logger
				@logger.error(e) if @logger
				response.errors.push(WeblogPluginError.new(
					"ブログ記事編集エラー(メッセージ = #{e.message})",
					"ブログ記事の編集に失敗しました(メッセージ = #{e.message})。"))
			end
		else
			@logger.error("投稿ＩＤの指定がありません。") if @logger
			response.errors.push(WeblogPluginError.new(
				"投稿ＩＤ指定不足",
				"投稿ＩＤの指定がありませんでした。"))
		end

		@logger.debug("Finish #{self.class.name}#edit ... result = false") if @logger && @logger.debug?
		return response
	end

	def header_alias
		return M2W_WEBLOG_POST_HEADER_ALIAS
	end

	def before(client, request, response)
	end

	def after(client, request, response)
	end

	def edit_article(client, blogid, postid, header, dateCreated)
		raise WeblogPluginError.new(
			"未実装エラー",
			"実装されていません。")
	end

end

==> m2w-1.3.8.zip: plugin/weblog/lib/standard_edit.rb <==
# coding: UTF-8

require 'plugin/weblog/lib/attachment_media_poster'
require 'plugin/weblog/lib/related_media_poster'
require 'plugin/weblog/lib/standard_command'
require 'plugin/weblog/lib/weblog_plugin_error'
require 'plugin/weblog/lib/weblog_plugin_warning'

#=標準のブログ編集投稿用ウェブログプラグイン
#
# 最初の著者:: トゥイー
# リポジトリ情報:: $Id: standard_edit.rb 941 2013-01-08 06:41:56Z toy_dev $
# 著作権:: Copyright (C) Ownway.info, 2011 - 2013. All rights reserved.
# ライセンス:: CPL(Common Public Licence)
class StandardEdit_WeblogPlugin < StandardCommand_WeblogPlugin

	def edit(request)
		@logger.debug("Start  #{self.class.name}#edit ... endpoint = #{@parent.endpoint}, header = #{request.header.keys}") if @logger && @logger.debug?

		client = @parent.client
		formatter = @parent.formatter
		formatter.logger = @logger
		postid = request.header['postid']
		response = Mail2WeblogResponse.new

		if postid != nil then
			begin
				before(client, request, response)

				vars = {
					:postid => postid,
					M2W_FORMAT_PLUGIN_CONF_HEADER_NAME => request.header[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME]
				}
				vars.merge!(request.header)

				# 書式プラグインの事前処理を行う
				formatter.preset(request, vars, response.errors, response.warnings)

				# 未貼り付け画像を先頭に貼り付ける
				if request.contents['description'] then
					images = ''
					request.attachments.each_with_index do |attachment, i|
						attachment_index = i + 1
						if %r!^image/! =~ Mime.new.mime(attachment.filename) &&
								(vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME] == nil ||
								vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_PASTED_ATTACHMENT_VAR_NAME] == nil ||
								vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_PASTED_ATTACHMENT_VAR_NAME][attachment_index.to_s] == nil) then
							vars.deep_merge!(@parent.plugin_manager.call_format_plugin_preset('img', attachment_index.to_s, vars))
							images << "{{img(#{attachment_index})}}\n\n"
						end
					end
					request.contents['description'] = "#{images}#{request.contents['description']}"
				end

				# 投稿日付を取得する
				header = request.header.clone
				dateCreated = @parent.parse_date(header['dateCreated'], Time.now, response.errors, response.warnings)
				if header['dateCreated'] != nil then
					header['dateCreated'] = @parent.get_date(dateCreated)
				end

				# ファイル転送の事前準備をする
				media_posters = []
				# 添付ファイルを投稿対象に追加する
				if request.attachments != nil then
					request.attachments.each_with_index do |attachment, i|
						attachment_index = i + 1
						media_name = @parent.get_attachment_filepath(postid, dateCreated, attachment_index, attachment.filename)
						thumbnail_name = @parent.get_thumbnail_filepath(postid, dateCreated, attachment_index, attachment.filename)
						media_posters.push(AttachmentMediaPoster.new(attachment, attachment_index, media_name, thumbnail_name, vars))
					end
				end
				# 関連ファイルを投稿対象に追加する
				if request.related_attachments != nil then
					request.related_attachments.each_with_index do |related_attachment, i|
						related_attachment_index = i + 1
						media_name = "rel#{postid}_#{related_attachment_index}#{File.extname(related_attachment.filename)}"
						thumbnail_name = "relthumbs#{postid}_#{related_attachment_index}#{File.extname(related_attachment.filename)}"
						media_posters.push(RelatedMediaPoster.new(related_attachment, media_name, thumbnail_name, @parent.plugin_manager, vars))
					end
				end
				# 書式プラグインからのファイル転送指令を投稿対象に追加する
				if vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME] && vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_MEDIAS_VAR_NAME] then
					vars[M2W_FORMAT_PLUGIN_CONF_HEADER_NAME][M2W_WEBLOG_PLUGIN_CONF_MEDIAS_VAR_NAME].each do |media_name, media|
						media_posters.push(media)
					end
				end

				# ファイルを転送する
				vars[:attachment_urls] = {}
				vars[:thumbnail_urls] = {}
				vars[:related_attachment_urls] = {}
				vars[:related_thumbnail_urls] = {}
				post_medias(client, @parent.username, @parent.password, media_posters, response.errors, response.warnings)

				# 書式変換を行う
				begin
					formatted_contents = nil
					formatted_contents = formatter.format(request, vars, response.errors, response.warnings)
					header.merge!(formatted_contents)
				rescue => e
					@logger.error("ブログ記事の書式変換に失敗しました。") if @logger
					@logger.error(e) if @logger
					response.errors.push(WeblogPluginError.new(
						"書式変換エラー(メッセージ = #{e.message})",
						"ブログ記事の書式変換に失敗しました(メッセージ = #{e.message})。"))
					@logger.debug("Finish #{self.class.name}#edit ... result = false") if @logger && @logger.debug?
					return response
				end

				# ブログ記事を編集投稿する
				begin
					edit_article(client, postid, header, dateCreated)
				rescue => e
					@logger.error("ブログ記事の編集に失敗しました。") if @logger
					@logger.error(e) if @logger
					response.errors.push(WeblogPluginError.new(
						"ブログ記事編集エラー(メッセージ = #{e.message})",
						"ブログ記事の編集に失敗しました(メッセージ = #{e.message})。"))
					@logger.debug("Finish #{self.class.name}#edit ... result = false") if @logger && @logger.debug?
					return response
				end

				response[:original_content] = request.original_content
				response[:postid] = postid.to_s
				response[:attachment_urls] = vars[:attachment_urls]
				response[:thumbnail_urls] = vars[:thumbnail_urls]
				response[:title] = header['title']
				response[:formatted_contents] = formatted_contents

				after(client, request, response)

				@logger.debug("Finish #{self.class.name}#edit ... result = true") if @logger && @logger.debug?
				response.success = true
				return response
			rescue => e
				@logger.error("ブログ記事の編集に失敗しました。") if @logger
				@logger.error(e) if @logger
				response.errors.push(WeblogPluginError.new(
					"ブログ記事編集エラー(メッセージ = #{e.message})",
					"ブログ記事の編集に失敗しました(メッセージ = #{e.message})。"))
			end
		else
			@logger.error("投稿ＩＤの指定がありません。") if @logger
			response.errors.push(WeblogPluginError.new(
				"投稿ＩＤ指定不足",
				"投稿ＩＤの指定がありませんでした。"))
		end

		@logger.debug("Finish #{self.class.name}#edit ... result = false") if @logger && @logger.debug?
		return response
	end

	def header_alias
		return M2W_WEBLOG_POST_HEADER_ALIAS
	end

	def before(client, request, response)
	end

	def after(client, request, response)
	end

	def edit_article(client, postid, header, dateCreated)
		raise WeblogPluginError.new(
			"未実装エラー",
			"実装されていません。")
	end

end
